roc-dingo
============

Python Package to ingest RPW data into database.

This package has been initially designed to be run in the RPW Operations and Data Pipeline (RODP).
Contact the developer team for more details.

## Quickstart

To install package using [pip](https://pypi.org/project/pip-tools/):

```
pip install roc-dingo
```

## Authors

- xavier dot bonnin at obspm dot fr
- florence dot henry at obspm dot fr

## License

This project is licensed under CeCILL 2.1.

## Acknowledgments

* Solar Orbiter / RPW Operation Centre (ROC) team